@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::2_0::Direct::Cat;
-$Search::Elasticsearch::Client::2_0::Direct::Cat::VERSION = '2.01';
+package Search::Elasticsearch::Client::1_0::Direct::Cat;
+$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '2.02';
 use Moo;
-with 'Search::Elasticsearch::Role::API::2_0';
+with 'Search::Elasticsearch::Role::API::1_0';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
@@ -24,11 +24,11 @@ sub help {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Cat - A client for running cat debugging requests
+Search::Elasticsearch::Client::1_0::Direct::Cat - A client for running cat debugging requests
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 DESCRIPTION
 
@@ -209,22 +209,6 @@ Query string parameters:
 See the L<cat master docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-master.html>
 for more information.
 
-=head2 C<nodeattrs()>
-
-    say $e->cat->nodeattrs();
-
-Returns the node attributes set per node.
-
-Query string parameters:
-    C<h>,
-    C<help>,
-    C<local>,
-    C<master_timeout>,
-    C<v>
-
-See the L<cat nodeattrs docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-nodeattrs.html>
-for more information.
-
 =head2 C<nodes()>
 
     say $e->cat->nodes();
@@ -279,7 +263,7 @@ for more information.
         index => 'index' | \@indices    # optional
     );
 
-Provides a view of shard replication. It will show information
+Provides a is a view of shard replication. It will show information
 anytime data from at least one shard is copying to a different node.
 It can also show up on cluster restarts. If your recovery process seems
 stuck, try it to see if there’s any movement using C<recovery()>.
@@ -294,22 +278,6 @@ Query string parameters:
 See the L<cat recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-recovery.html>
 for more information.
 
-=head2 C<repositories()>
-
-    say $e->cat->repositories()
-
-Provides a list of registered snapshot repositories.
-
-Query string parameters:
-    C<h>,
-    C<help>,
-    C<local>,
-    C<master_timeout>,
-    C<v>
-
-See the L<cat repositories docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-repositories.html>
-for more information.
-
 =head2 C<segments()>
 
     say $e->cat->segments(
@@ -345,24 +313,6 @@ Query string parameters:
 See the L<cat shards docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-shards.html>
 for more information.
 
-=head2 C<snapshots()>
-
-    say $e->cat->snapshots(
-        repository => 'repository' | \@repositories # required
-    )
-
-Provides a list of all snapshots that belong to the specified repositories.
-
-Query string parameters:
-    C<h>,
-    C<help>,
-    C<ignore_unavailable>,
-    C<master_timeout>,
-    C<v>
-
-See the L<cat snapshots docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-snapshots.html>
-for more information.
-
 =head2 C<thread_pool()>
 
     say $e->cat->thread_pool(
