@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::CxnPool::Sniff;
-$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '2.01';
+$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '2.02';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 requires 'next_cxn', 'sniff';
@@ -44,8 +44,8 @@ sub parse_sniff {
     for my $node_id ( keys %$nodes ) {
         my $data = $nodes->{$node_id};
 
-        my $host = $data->{ $protocol . "_address" } or next;
-        $host =~ s{^inet\[[^/]*/([^\]]+)\]}{$1};
+        my $host = $self->_extract_host( $data->{ $protocol . "_address" } )
+            or next;
 
         $host = $self->should_accept_node( $host, $node_id, $data )
             or next;
@@ -72,6 +72,16 @@ sub parse_sniff {
     return 1;
 }
 
+#===================================
+sub _extract_host {
+#===================================
+    my $self = shift;
+    my $host = shift || return;
+    $host =~ s{^inet\[(.+)\]$}{$1};
+    $host =~ s{^[^/]+/}{};
+    return $host;
+}
+
 #===================================
 sub should_accept_node { return $_[1] }
 #===================================
@@ -88,7 +98,7 @@ Search::Elasticsearch::Role::CxnPool::Sniff - A CxnPool role for connecting to a
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 CONFIGURATION
 
